package
Version:
v0.3.0
Opens a new window with list of versions in this module.
Published: Feb 21, 2026
License: MIT
Opens a new window with license information.
Imports: 11
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
var AppsCmd = &cobra.Command{
Use: "apps",
Short: "Manage applications",
Long: `List and manage applications in your Google Play Console account.`,
}
type AppInfo struct {
PackageName string `json:"package_name"`
DisplayName string `json:"display_name,omitempty"`
}
AppInfo represents basic app information
Source Files
¶
Click to show internal directories.
Click to hide internal directories.