diff

package
v0.4.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 25, 2026 License: MIT Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var DiffCmd = &cobra.Command{
	Use:   "diff",
	Short: "Show differences between draft edit and live app",
	Long: `Compare the current draft edit state against the live version.

This helps you review pending changes before committing an edit.
If no edit exists, shows the current live state as a summary.`,
	RunE: runDiff,
}

DiffCmd compares edit state vs live version

Functions

This section is empty.

Types

type DiffResult

type DiffResult struct {
	Section string      `json:"section"`
	Status  string      `json:"status"`
	Current interface{} `json:"current,omitempty"`
}

DiffResult represents the diff output

type ListingSummary

type ListingSummary struct {
	Language string `json:"language"`
	Title    string `json:"title,omitempty"`
}

ListingSummary represents a listing's current state

type TrackSummary

type TrackSummary struct {
	Track        string  `json:"track"`
	Status       string  `json:"status,omitempty"`
	VersionCode  int64   `json:"version_code,omitempty"`
	UserFraction float64 `json:"user_fraction,omitempty"`
}

TrackSummary represents a track's current state

Jump to