cli

package
v0.4.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 25, 2026 License: MIT Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CheckConfirm

func CheckConfirm(cmd *cobra.Command) error

CheckConfirm validates confirmation for destructive operations

func GetPackageName

func GetPackageName() string

GetPackageName returns the package name from flag, env, or config

func GetProfile

func GetProfile() string

GetProfile returns the profile name from flag, env, or config

func GetTimeout

func GetTimeout() string

GetTimeout returns the timeout duration string

func IsDryRun

func IsDryRun() bool

IsDryRun returns whether dry-run mode is enabled

func RequirePackage

func RequirePackage(cmd *cobra.Command) error

RequirePackage validates package name is set

func SetDryRun

func SetDryRun(d bool)

SetDryRun sets the dry-run mode

func SetPackageName

func SetPackageName(p string)

SetPackageName sets the package name from the flag

func SetProfile

func SetProfile(p string)

SetProfile sets the profile from the flag

func SetTimeout

func SetTimeout(t string)

SetTimeout sets the timeout from the flag

Types

This section is empty.

Jump to