Documentation
¶
Index ¶
- Variables
- func CheckAndEnableAPI(operation func() error) error
- func HandleAPIEnablement(apiErr *APIEnablementError) error
- type APIEnablementError
- type Client
- func (c *Client) Apps() *androidpublisher.ApplicationsService
- func (c *Client) Context() (context.Context, context.CancelFunc)
- func (c *Client) CreateEdit() (*Edit, error)
- func (c *Client) Edits() *androidpublisher.EditsService
- func (c *Client) GetEdit(editID string) (*Edit, error)
- func (c *Client) GetPackageName() string
- func (c *Client) GetService() *androidpublisher.Service
- func (c *Client) Grants() *androidpublisher.GrantsService
- func (c *Client) InAppProducts() *androidpublisher.InappproductsService
- func (c *Client) Monetization() *androidpublisher.MonetizationService
- func (c *Client) Purchases() *androidpublisher.PurchasesService
- func (c *Client) Reviews() *androidpublisher.ReviewsService
- func (c *Client) Users() *androidpublisher.UsersService
- type Edit
- func (e *Edit) APKs() *androidpublisher.EditsApksService
- func (e *Edit) Bundles() *androidpublisher.EditsBundlesService
- func (e *Edit) Close()
- func (e *Edit) Commit() error
- func (e *Edit) Context() context.Context
- func (e *Edit) Delete() error
- func (e *Edit) DeobfuscationFiles() *androidpublisher.EditsDeobfuscationfilesService
- func (e *Edit) Details() *androidpublisher.EditsDetailsService
- func (e *Edit) ExpansionFiles() *androidpublisher.EditsExpansionfilesService
- func (e *Edit) ID() string
- func (e *Edit) Images() *androidpublisher.EditsImagesService
- func (e *Edit) Listings() *androidpublisher.EditsListingsService
- func (e *Edit) Testers() *androidpublisher.EditsTestersService
- func (e *Edit) Tracks() *androidpublisher.EditsTracksService
- func (e *Edit) Validate() error
Constants ¶
This section is empty.
Variables ¶
var RequiredAPIs = map[string]string{
"androidpublisher.googleapis.com": "Google Play Android Developer API",
"playdeveloperreporting.googleapis.com": "Google Play Developer Reporting API",
}
RequiredAPIs lists all APIs that might be needed by the CLI
Functions ¶
func CheckAndEnableAPI ¶
CheckAndEnableAPI wraps an API call and handles enablement if needed
func HandleAPIEnablement ¶
func HandleAPIEnablement(apiErr *APIEnablementError) error
HandleAPIEnablement provides an interactive flow to enable a required API
Types ¶
type APIEnablementError ¶
type APIEnablementError struct {
APIName string
APITitle string
ProjectID string
ActivationURL string
OriginalError error
}
APIEnablementError represents an error when an API needs to be enabled
func ParseAPIEnablementError ¶
func ParseAPIEnablementError(err error) *APIEnablementError
ParseAPIEnablementError checks if an error is due to a disabled API and extracts the relevant information
func (*APIEnablementError) Error ¶
func (e *APIEnablementError) Error() string
type Client ¶
type Client struct {
// contains filtered or unexported fields
}
Client wraps the Android Publisher API client
func (*Client) Apps ¶
func (c *Client) Apps() *androidpublisher.ApplicationsService
Apps returns the applications service
func (*Client) Context ¶
func (c *Client) Context() (context.Context, context.CancelFunc)
Context returns a context with timeout
func (*Client) CreateEdit ¶
CreateEdit creates a new edit session
func (*Client) Edits ¶
func (c *Client) Edits() *androidpublisher.EditsService
Edits returns the edits service
func (*Client) GetPackageName ¶
GetPackageName returns the package name
func (*Client) GetService ¶
func (c *Client) GetService() *androidpublisher.Service
GetService returns the underlying Android Publisher service
func (*Client) Grants ¶
func (c *Client) Grants() *androidpublisher.GrantsService
Grants returns the grants service
func (*Client) InAppProducts ¶
func (c *Client) InAppProducts() *androidpublisher.InappproductsService
InAppProducts returns the in-app products service
func (*Client) Monetization ¶
func (c *Client) Monetization() *androidpublisher.MonetizationService
Monetization returns the monetization service
func (*Client) Purchases ¶
func (c *Client) Purchases() *androidpublisher.PurchasesService
Purchases returns the purchases service
func (*Client) Reviews ¶
func (c *Client) Reviews() *androidpublisher.ReviewsService
Reviews returns the reviews service
func (*Client) Users ¶
func (c *Client) Users() *androidpublisher.UsersService
Users returns the users service
type Edit ¶
type Edit struct {
// contains filtered or unexported fields
}
Edit represents an active edit session
func (*Edit) APKs ¶
func (e *Edit) APKs() *androidpublisher.EditsApksService
APKs returns the APKs service for this edit
func (*Edit) Bundles ¶
func (e *Edit) Bundles() *androidpublisher.EditsBundlesService
Bundles returns the bundles service for this edit
func (*Edit) DeobfuscationFiles ¶
func (e *Edit) DeobfuscationFiles() *androidpublisher.EditsDeobfuscationfilesService
DeobfuscationFiles returns the deobfuscation files service for this edit
func (*Edit) Details ¶
func (e *Edit) Details() *androidpublisher.EditsDetailsService
Details returns the details service for this edit
func (*Edit) ExpansionFiles ¶
func (e *Edit) ExpansionFiles() *androidpublisher.EditsExpansionfilesService
ExpansionFiles returns the expansion files service for this edit
func (*Edit) Images ¶
func (e *Edit) Images() *androidpublisher.EditsImagesService
Images returns the images service for this edit
func (*Edit) Listings ¶
func (e *Edit) Listings() *androidpublisher.EditsListingsService
Listings returns the listings service for this edit
func (*Edit) Testers ¶
func (e *Edit) Testers() *androidpublisher.EditsTestersService
Testers returns the testers service for this edit
func (*Edit) Tracks ¶
func (e *Edit) Tracks() *androidpublisher.EditsTracksService
Tracks returns the tracks service for this edit