Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CheckConfirm ¶
CheckConfirm validates confirmation for destructive operations
func GetPackageName ¶
func GetPackageName() string
GetPackageName returns the package name from flag, env, or config
func GetProfile ¶
func GetProfile() string
GetProfile returns the profile name from flag, env, or config
func RequirePackage ¶
RequirePackage validates package name is set
func SetPackageName ¶
func SetPackageName(p string)
SetPackageName sets the package name from the flag
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.